<?php

/**        Function called to complete substitution array (before generating on ODT, or a personalized email)
 *        functions xxx_completesubstitutionarray are called by make_substitutions() if file
 *        is inside directory htdocs/core/substitutions
 *
 * @param    array     $substitutionarray Array with substitution key=>val
 * @param    Translate $langs             Output langs
 * @param    Object    $object            Object to use to get values
 *
 * @return    void                    The entry parameter $substitutionarray is modified
 */
function mymodule_completesubstitutionarray(&$substitutionarray, $langs, $object, $parameters)
{
    global $conf, $db;
    $substitutionarray['__TOTAL_AMOUNT__'] = is_object($object) ? price($object->total_ttc) : '';

    $listtable = '';
    $total_amount_incl_taxes = 0;
    $total_topay_incl_taxes = 0;

    $massaction  = filter_input(INPUT_POST, 'massaction', FILTER_SANITIZE_STRING);
    $toselect    = filter_input(INPUT_POST, 'toselect', FILTER_DEFAULT, FILTER_FORCE_ARRAY);
    $contextpage = filter_input(INPUT_POST, 'contextpage', FILTER_SANITIZE_STRING);

    if (( 'presend' === $massaction || 'confirm_presend' === $massaction ) && count($toselect)) {
        $listofobjectref = ! empty($parameters['listofobjectref']) ? $parameters['listofobjectref'] : array();

        if ('proposallist' == $contextpage) {
            $objectclass = 'Propal';
        } elseif ('invoicelist' == $contextpage) {
            $objectclass = 'Facture';
        }

        // workaround for when  listofobjectref isn't passed with paramaters
        if (empty($listofobjectref)) {
            foreach ($toselect as $toselectid) {
                $objecttmp = new $objectclass($db);
                $result    = $objecttmp->fetch($toselectid);
                if ($result > 0) {
                    $thirdpartyid = $objecttmp->fk_soc ? $objecttmp->fk_soc : $objecttmp->socid;
                    if ($objecttmp->element == 'societe') {
                        $thirdpartyid = $objecttmp->id;
                    }
                    if ($objecttmp->element == 'expensereport') {
                        $thirdpartyid = $objecttmp->fk_user_author;
                    }
                    $listofobjectref[ $thirdpartyid ][ $toselectid ] = $objecttmp;
                }
            }
        }

        if (! empty($listofobjectref)) {
            $thirdparty = new Societe($db);

            foreach ($listofobjectref as $thirdpartyid => $objects) {
                $result = $thirdparty->fetch($thirdpartyid);

                if ($result < 0) {
                    dol_print_error($db);
                    exit;
                }

                $currency = $conf->multicurrency->enabled && !empty($thirdparty->multicurrency_code) ? $thirdparty->multicurrency_code : $conf->currency;

                $listtable .= '<br>';
                $listtable .= '<table border="0" style="border:none; dborder-collapse: collapse;">';

                $listtable .= '<tr><td style="border:none;">';
                $listtable .= '<span style="font-size:80%">' . $langs->transnoentities("AmountInCurrency", $langs->transnoentitiesnoconv("Currency".$currency)) . '</span>';
                $listtable .= '</tr></td>';

                $listtable .= '<tr><td style="border:none;">';

                $listtable .= '<table border="1" cellpadding="8" cellspacing="0" style="border-collapse: collapse;">';
                $listtable .= '<thead>';
                if (count($listofobjectref) > 1) {
                    $listtable .= '<tr><th colspan="' . ( $objectclass === 'Facture' ? 5 : 3 ) . '">'
                                  . $thirdparty->name
                                  . '</th></tr>';
                    $listtable .= '<tr>';
                }
                $listtable .= '<th>' . $langs->trans('Numero') . '</th>';
                $listtable .= '<th align="center" style="text-align: center">' . $langs->trans('Date') . '</th>';
                $listtable .= '<th align="right" style="text-align: right">' . $langs->trans('AmountTTCShort') . '</th>';

                if ($objectclass === 'Facture') {
                    $listtable .= '<th align="right" style="text-align: right; padding: 5px 5px 5px 10px;">' . $langs->trans('Paid') . '</th>';
                    $listtable .= '<th align="right" style="text-align: right">' . $langs->trans('RemainderToPay') . '</th>';
                }
                $listtable .= '</tr></thead>';
                $listtable .= '<tbody>';

                foreach ($objects as $object) {
                    $date      = isset($object->date) ? dol_print_date($object->date, 'day', 0, $langs) : '';
                    $total_incl_taxes = ( $conf->multicurrency->enabled && $object->multicurrency_tx != 1 ) ? $object->multicurrency_total_ttc : $object->total_ttc;

                    $total_amount_incl_taxes += $total_incl_taxes;

                    if ($objectclass === 'Facture') {
                        $paid = $object->getSommePaiement(( $conf->multicurrency->enabled && $object->multicurrency_tx != 1 ) ? 1 : 0);

                        $amount_credit_notes = $object->getSumCreditNotesUsed(( $conf->multicurrency->enabled && $object->multicurrency_tx != 1 ) ? 1 : 0);
                        $amount_deposit     = $object->getSumDepositsUsed(( $conf->multicurrency->enabled && $object->multicurrency_tx  != 1 ) ? 1 : 0);

                        $to_pay = price2num($total_incl_taxes - $paid - $amount_credit_notes - $amount_deposit, 'MT');
                        if ($object->paye) {
                            $to_pay=0;
                        }

                        $total_topay_incl_taxes += $to_pay;
                    } else {
                        $total_topay_incl_taxes = $total_amount_incl_taxes;
                    }

                    $listtable .= '<tr>';
                    $listtable .= '<td>' . $object->ref . '</td>';
                    $listtable .= '<td align="center" style="text-align: center">' . $date . '</td>';
                    $listtable .= '<td align="right"  style="text-align: right">' . price($total_incl_taxes) . '</td>';

                    if ($objectclass === 'Facture') {
                        $listtable .= '<td align="right" style="text-align: right">' . price($paid) . '</td>';
                        $listtable .= '<td align="right"  style="text-align: right">' . price($to_pay) . '</td>';
                    }

                    $listtable .= '</tr>';
                }

                $listtable .= '</tbody>';
                $listtable .= '<tfoot>';
                $listtable .= '<tr>';
                $listtable .= '<th scope="row" colspan="' . ( $objectclass === 'Facture' ? 4 : 2 ) . '"   align="right" style="text-align: right">';
                $listtable .= $langs->trans('TotalTTC');
                $listtable .= '</th>';
                $listtable .= '<td  align="right" style="text-align: right">';
                $listtable .= price($total_topay_incl_taxes);
                $listtable .= '</td>';
                $listtable .= '</tr>';
                $listtable .= '</tfoot>';
                $listtable .= '</table>';

                $listtable .= '</tr></td></table>';
            }
        }
    }

    $substitutionarray['__LIST_TABLE__']                = $listtable;
    $substitutionarray['__TOTAL_AMOUNT_INCL_TAXES__']   = price($total_amount_incl_taxes);
    $substitutionarray['__TOTAL_TOPAY_INCL_TAXES__']    = price($total_topay_incl_taxes);
    $substitutionarray['__TOTAL_AMOUNT_INCL_TAXES_CURR__']   = price($total_amount_incl_taxes) . ' ' . $langs->transnoentitiesnoconv("Currency".$currency);
    $substitutionarray['__TOTAL_TOPAY_INCL_TAXES_CURR__']    = price($total_topay_incl_taxes) . ' ' . $langs->transnoentitiesnoconv("Currency".$currency);
}
